==> gravitino-1.0.1-src.tar.gz: gravitino-1.0.1-src/clients/client-python/gravitino/dto/rel/partitions/partition_dto.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.


from abc import abstractmethod
from enum import Enum, unique

from gravitino.api.expressions.partitions.partition import Partition


class PartitionDTO(Partition):
    """Represents a Partition Data Transfer Object (DTO) that implements the Partition interface."""

    @unique
    class Type(str, Enum):
        """Type of the partition."""

        RANGE = "range"
        """The range partition type."""
        LIST = "list"
        """The list partition type."""
        IDENTITY = "identity"
        """The identity partition type."""

    @abstractmethod
    def type(self) -> Type:
        """Gets the type of the partition.

        Returns:
            Type: The type of the partition.
        """
        pass  # pragma: no cover

==> gravitino-1.1.0-src.tar.gz: gravitino-1.1.0-src/clients/client-python/gravitino/dto/rel/partitions/partition_dto.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.


from abc import abstractmethod
from enum import Enum, unique

from gravitino.api.rel.partitions.partition import Partition


class PartitionDTO(Partition):
    """Represents a Partition Data Transfer Object (DTO) that implements the Partition interface."""

    @unique
    class Type(str, Enum):
        """Type of the partition."""

        RANGE = "range"
        """The range partition type."""
        LIST = "list"
        """The list partition type."""
        IDENTITY = "identity"
        """The identity partition type."""

    @abstractmethod
    def type(self) -> Type:
        """Gets the type of the partition.

        Returns:
            Type: The type of the partition.
        """
        pass  # pragma: no cover
